#' Calculate the type I error rate of the weighted Simes test
#'
#' @param rho the correlation coefficient between two test statistics
#' @param adjFct a pre-specified constant in the improved weighted Hochberg procedure, called the adjustment factor or k value
#' @param alpha the significance level
#' @param alphavec a numeric vector of two values representing the weighted significance levels assigned to the two hypotheses
#'
#' @returns the type I error rate
#' @export
#'
#' @importFrom mvtnorm pmvnorm
#' @importFrom mvtnorm Miwa
#' @importFrom stats qnorm
#' @author Jiangtao Gou
#' @references
#' Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
#' @examples
#' typeIerror_trimSimes_mvtnorm(rho = 0, adjFct = 0, alpha = 0.05)
typeIerror_Simes_mvtnorm <- function (rho, adjFct = 0, alpha, alphavec = c(alpha/2, alpha/2)) {
  # R20241111a.R
  # Based on find_k_target_mvtnorm in R20241108d.R
  # adjFct <- k
  sigma <- matrix(c(1, rho, rho, 1), nrow = 2)
  # Middle
  lower <- c(-1000, -1000)
  upper <- c(qnorm(alpha), qnorm(alpha))
  RegionMiddleRslt <- mvtnorm::pmvnorm(lower = lower, upper = upper, mean = rep(0, 2), sigma = sigma, algorithm = mvtnorm::Miwa(steps = 128))
  RegionMiddle <- as.numeric(RegionMiddleRslt)
  # Left
  lower <- c(-1000, qnorm(alpha))
  upper <- c(qnorm(  alphavec[1]*(1+alphavec[2]*adjFct) ), +1000 )
  RegionLeftRslt <- mvtnorm::pmvnorm(lower = lower, upper = upper, mean = rep(0, 2), sigma = sigma, algorithm = mvtnorm::Miwa(steps = 128))
  RegionLeft <- as.numeric(RegionLeftRslt)
  # Bottom
  lower <- c(qnorm(alpha), -1000)
  upper <- c(+1000,  qnorm(  alphavec[2]*(1+alphavec[1]*adjFct)) )
  RegionBottomRslt <- mvtnorm::pmvnorm(lower = lower, upper = upper, mean = rep(0, 2), sigma = sigma, algorithm = mvtnorm::Miwa(steps = 128))
  RegionBottom <- as.numeric(RegionBottomRslt)
  #
  Region <- RegionMiddle + RegionLeft + RegionBottom
  #
  return (Region)
}
